#[repr(transparent)]pub struct AvatarData {
inner: TypedObjectRef<AvatarData, ()>,
phantom: PhantomData<()>,
}Expand description
Data about a User’s or Room’s avatar.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<AvatarData, ()>phantom: PhantomData<()>Implementations
Sourceimpl AvatarData
impl AvatarData
Sourcepub fn image(&self) -> <RefCell<Option<AvatarImage>> as Property>::Value
pub fn image(&self) -> <RefCell<Option<AvatarImage>> as Property>::Value
The data of the user-defined image.
Sourcepub fn set_image<'a>(
&self,
value: Option<impl Borrow<<<RefCell<Option<AvatarImage>> as Property>::Value as HasParamSpec>::SetValue>>,
)
pub fn set_image<'a>( &self, value: Option<impl Borrow<<<RefCell<Option<AvatarImage>> as Property>::Value as HasParamSpec>::SetValue>>, )
The data of the user-defined image.
Sourcepub fn display_name(&self) -> <RefCell<String> as Property>::Value
pub fn display_name(&self) -> <RefCell<String> as Property>::Value
The display name used as a fallback for this avatar.
Sourcepub fn set_display_name<'a>(
&self,
value: impl Borrow<<<RefCell<String> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_display_name<'a>( &self, value: impl Borrow<<<RefCell<String> as Property>::Value as HasParamSpec>::SetValue>, )
The display name used as a fallback for this avatar.
Sourcepub fn connect_image_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_image_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the image property
Sourcepub fn connect_display_name_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_display_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the display-name property
Sourcepub fn notify_image(&self)
pub fn notify_image(&self)
Notify listeners of a change in the image property
Sourcepub fn notify_display_name(&self)
pub fn notify_display_name(&self)
Notify listeners of a change in the display-name property
Sourceimpl AvatarData
impl AvatarData
Sourcepub(crate) async fn as_notification_icon(
&self,
inhibit_image: bool,
) -> Option<Texture>
pub(crate) async fn as_notification_icon( &self, inhibit_image: bool, ) -> Option<Texture>
Get this avatar as a notification icon.
If inhibit_image is set, the image of the avatar will not be used.
Returns None if an error occurred while generating the icon.